@@ -5,12 +5,14 @@ inline Group const &AgeGroupVSD::group() const
     return d_group;
 }
 
-inline uint16_t AgeGroupVSD::beginAge() const
+    // by growth/nextrange.cc
+inline double AgeGroupVSD::beginAge() const
 {
     return d_group.begin();
 }
 
-inline uint16_t AgeGroupVSD::endAge() const
+    // by growth/nextrange.cc
+inline double AgeGroupVSD::endAge() const
 {
     return d_group.end();
 }
