@@ -1,7 +1,9 @@
-#define XERR
+#define XERR "analysis"
 #include "analysis.ih"
 
-    // the error count is reset by the Simulator
+// the error count is reset by the Simulator
+
+    // by simulator/run.cc
 
 Analysis::Analysis(std::istream &&stream, uint16_t lineNr)
 {
