@@ -1,8 +1,10 @@
-#define XERR
+#define XERR "analysis"
 #include "analysis.ih"
 
 //extern Parser *pPtr;
 
+    // by simulator/run.cc
+
 void Analysis::run()
 {
     requireBase();              // the base directory must be (made) available
