@@ -1,15 +1,13 @@
-//#define XERR
+#define XERR
 #include "beir7.ih"
 
-//Tumor:
-//    #       eta     beta    spread  dist.
-//    beir7:  -2.0    0.51    0.32    Normal
-
-// Tumor:
+//#Tumor:
 //    Beir7:
 //            #       eta     beta    spread  dist.
 //        breast:     -2.0    0.51    0.32    Normal
 //
+
+//#Beir7
 //                                      Read by BetaDist (./betadist)
 //                             >>> dist: not used unless spread == true
 //        # LC:    eta   beta  dist    constant factor   aParam    bParam
@@ -23,18 +21,19 @@ Beir7::Beir7()
     switch (Globals::simulationType())
     {
         case BREAST:
-            Parser::extract( Parser::one({ "Tumor:", "Beir7:", "breast:" }),
+            Parser::extract( Parser::one({ "Beir7:", "breast:" }),
                             d_eta, d_vsd);
         break;
 
         case MALE:
-            Parser::extract( Parser::one({ "Tumor:", "Beir7:", "male:" }),
+            Parser::extract( Parser::one({ "Beir7:", "male:" }),
                             d_eta, d_vsd);
         break;
 
         case FEMALE:
-            Parser::extract( Parser::one({ "Tumor:", "Beir7:", "female:" }),
+            Parser::extract( Parser::one({ "Beir7:", "female:" }),
                             d_eta, d_vsd);
         break;
     }
 }
+
