@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "costs.ih"
 
 size_t Costs::cost(double diameter) const
