@@ -23,7 +23,7 @@
 class Costs
 {
               // lower diam., cost
-    typedef std::pair<double, size_t>     CostPair;
+    using CostPair = std::pair<double, size_t>;
 
     StringVect d_base;
 
