@@ -3,7 +3,7 @@
 
 void Costs::setLungCancer()
 {
-    uint16_t unused;            // = modbase->cost(), extracted by ModBase
+    size_t unused;            // = modbase->cost(), extracted by ModBase
 
     if (not Parser::extract(Parser::one(d_base), unused,
                             d_usingCosts,
