@@ -3,19 +3,19 @@
 
 void Costs::setVariables(bool lungCancer)
 {
-    // d_base = { "Costs:", "???", "????"}
-
     if (not lungCancer)
     {
-        d_base.resize(2);
-        d_base[1] = "biop:";
+        d_base.back() = "biop:";
         Parser::nonNegative(d_base, d_usingCosts);
         d_treatment = &Costs::otherTreatment;
         return;
     }
 
+    // below: ony used for LC simulations
+
             // reset d_base to read the CT: costs
-    d_base = StringVect{ "Modalities:", "CT:", "costs:" };
+    d_base.back() = "CT:";
+    d_base.push_back("costs:");
 
     d_treatmentCosts.resize(2);
     d_treatment = &Costs::lcTreatment;
