@@ -1,6 +1,8 @@
-//#define XERR
+#define XERR "densities"
 #include "densities.ih"
 
+    // by loop/loop1.cc
+
 Densities::Densities()
 :
     d_base{ "BreastDensities:", "ageGroup:" }
