@@ -2,6 +2,7 @@
 #define INCLUDED_DISTRIBUTION_
 
 #include <iosfwd>
+#include <cmath>
 
 #include "../typedefs/typedefs.h"
 
@@ -28,6 +29,8 @@ class Distribution
                                             // vary*/accept functions below)
     double (Distribution::*d_value)(double orgValue) const;
 
+    bool d_exp;
+
     static StringVect s_name;
     static unsigned s_width;
     static unsigned s_precision;
@@ -45,6 +48,8 @@ class Distribution
                                                 // integral part
         static void fmt(unsigned intWidth, unsigned precision);
 
+        void ln();                              // ln(d_confValue)          .f
+
         DistType type() const;                                          //  .f
 
         double value(double orgValue) const;    // return varied value (if  .f
