@@ -45,7 +45,7 @@ istream &Distribution::extract(istream &in)
     if (d_confValue < 0)
     {
         Err::msgTxt(Err::NEGATIVE);
-        in.fail();
+        in.setstate(ios::failbit);
         return in;
     }
                 // value was extracted: the distribtion name must be next
@@ -56,7 +56,7 @@ istream &Distribution::extract(istream &in)
     }
 
     Err::msgTxt(Err::UNDEFINED_DIST);
-    in.fail();
+    in.setstate(ios::failbit);
 
     return in;
 }
