@@ -3,12 +3,14 @@ inline Group::Group(Series series)
     d_series(series)
 {}
 
-inline uint16_t Group::begin() const
+    // by probgroup.f (begin())
+inline double Group::begin() const
 {
     return d_begin;
 }
 
-inline uint16_t Group::end() const
+    // by probgroup.f (end())
+inline double Group::end() const
 {
     return d_end;
 }
