@@ -18,14 +18,14 @@ class Group
 
     Series      d_series;
 
-    uint16_t    d_begin = 0;
-    uint16_t    d_end = END_AGE;
+    mutable double d_begin = 0;         // connects() may change d_begin
+    double         d_end = END_AGE;
 
     public:
         Group(Series series);                                           // .f
 
-        uint16_t begin() const;                                         // .f
-        uint16_t end() const;                                           // .f
+        double begin() const;                                           // .f
+        double end() const;                                             // .f
 
             // Err::NOT_CONSECUTIVE if false
         template <HasGroup Type>                                      // .f
