@@ -6,6 +6,6 @@ bool Group::maxEnd()
     if (d_end != END_AGE)
         return false;
 
-    d_end = numeric_limits<uint16_t>::max();
+    d_end = Globals::uint16_max;
     return true;
 }
