@@ -27,11 +27,11 @@ class Growth
 {
     StringVect d_base;
 
-    bool    d_bc;               // --cancer: breast was specified
+    bool    d_bc;               // not --cancer: breast was specified
     double  d_start;
 
-    double  d_selfSD;
-    VSD     d_selfMean;
+    double  d_selfSD;           // SD of d_selfMean's mean value
+    VSD     d_selfMean;         // mean and SD/Distr. used when 'vary'is set
 
     AgeGroupVSDvect d_doublingTime;
     AgeGroupVSD const &(Growth::*d_ageGroupVSD)(uint16_t idx) const;
@@ -39,13 +39,13 @@ class Growth
     public:
         Growth();
 
-        AgeGroupVSD const &ageGroupVSD(uint16_t idx) const;
+        AgeGroupVSD const &ageGroupVSD(uint16_t idx) const;             // .f
 
         void vary(std::ostream &out);
 
-        double start() const;
-        VSD const &selfMu() const;
-        double selfSigma() const;
+        double start() const;                                           // .f
+        VSD const &selfMu() const;                                      // .f
+        double selfSigma() const;                                       // .f
 
         void writeParameters(std::ostream &out) const;
 
