@@ -4,17 +4,21 @@
 void Growth::setDoublingTime()
 {
     d_base.back() = "DoublingTime:";
+    size_t size = d_base.size();
 
-    if (not Globals::isBreast())
+    if (not Globals::isBreast())                        // used for LC sim.s
     {
         d_base.push_back("lung:");
 
         AgeGroupVSD spec{ VARY_NONNEG, true, false };   // useStdDev and don't
                                                         // extract Group
         Parser::extract(d_base, spec);
+        spec.ln();
+
         d_doublingTime.push_back(spec);
 
         d_ageGroupVSD = &Growth::ageGroupVSDlung;
+        d_base.resize(size);
         return;
     }
 
@@ -44,8 +48,12 @@ void Growth::setDoublingTime()
             continue;
         }
 
+        spec.ln();
+
         d_doublingTime.push_back(spec);
     }
 
     d_ageGroupVSD = &Growth::ageGroupVSDbreast;
+    d_base.resize(size);
 }
+
