@@ -10,7 +10,11 @@ void Growth::setSelfDetect()
     Parser::extract(d_base, d_selfSD, d_selfMean);
 
     if (0 <= d_selfSD)                          // OK if selfSD is positive
+    {
+        d_selfSD = log(d_selfSD);
+        d_selfMean.ln();
         return;
+    }
 
     Err::negative();
     d_selfSD = 0;
