@@ -10,7 +10,7 @@ void Growth::writeParameters(ostream &out) const
            setw(8) << ' ' << "start:                 " <<
                                         setw(4) << d_start << '\n' <<
            setw(8) << ' ' << "self-detect std.dev.:  " <<
-                                        setw(4) << d_selfSD << '\n' <<
+                                        setw(4) << exp(d_selfSD) << '\n' <<
            setw(8) << ' ' << "self-detect mean:      " <<
                                         d_selfMean << '\n' <<
            setw(6) << ' ' << "DoublingTime:\n";
@@ -25,9 +25,9 @@ void Growth::writeParameters(ostream &out) const
         auto const &first = d_doublingTime.front();
         double sd = first.stdDev();
         
-        out << setw(8) << ' ' << "value: " << first.value() << '\n';
+        out << setw(8) << ' ' << "value: " << exp(first.value()) << '\n';
         if (sd >= 0)
-            out << setw(8) << ' ' << "std.dev: " << sd << '\n';
+            out << setw(8) << ' ' << "std.dev: " << exp(sd) << '\n';
 
         out.put('\n');
     }
