@@ -6,6 +6,14 @@
 // Tumor:
 //     Incidence:
 //         Male:
+//              specifying 'riskTable' takes precedence: must be pairs of
+//              age proportion values. The ages must be increasing and must
+//              be >= 0 and <= MAX_AGE (-> enums)
+//
+//              riskTable: 25 0.001 
+//                          30 0.003 35 0.005 
+//                          40 0.009 45 0.014
+
 //             #                   value   spread  distr.
 //             lifetimeRisk:         .22   .005    Normal
 //             meanAge:            72.48  1.08     Normal
@@ -44,78 +52,47 @@
 
 #include <vector>
 #include <string>
+#include <memory>
 
-#include "../vsd/vsd.h"
+#include "../typedefs/typedefs.h"
 
-struct Incidence
+#include "../params/params.h"
+
+class Incidence
 {
-    class Params
-    {
-        friend class Incidence;
+    using ParamsPtr = std::unique_ptr<Params>;
 
-        unsigned d_idx;                                 // see setIncidence
-
-        double   d_prob = 1;
-
-        VSD     d_vsd[3] = { VSD{ VARY_PROB },          // lifetimeRisk
-                             VSD{ VARY_NONNEG },        // meanAge
-                             VSD{ VARY_NONNEG } };      // stdDev
-        public:
-            Params(unsigned idx);                                       // .f
-            void vary(std::ostream &out);                               // 1
-
-            double   prob() const;                                      // .f
-            VSD const &risk() const;           // lifeTimeRisk          // .f
-            VSD const &mean() const;                                    // .f
-
-            VSD const &stdDev() const;                                  // .f
-    };
-
-    private:
-        std::vector<Params> d_params;
-        DoubleVect d_cumProb;
-        DoubleVect2 d_tumorRisk;
-
-        static StringVect s_incidence;
+    std::vector<ParamsPtr> d_params;
+    DoubleVect d_cumProb;
+    DoubleVect2 d_tumorRisk;        // tumor risks per incidence category
 
     public:
         Incidence();
 
-        void vary(std::ostream &out);            // vary d_vsd's values     2
-
-        std::vector<Params> const &params() const;                      // .f
+        void vary(std::ostream &out);            // vary (d_vsd's) values
 
                                         // was: carrier() MODIFY for LC
         uint16_t index() const;         // randomly selected carrier index
 
-        DoubleVect2 const &tumorRisk() const;                           // .f
         DoubleVect const &tumorRisk(size_t idx) const;                  // .f
 
         void writeParameters(std::ostream &out) const;
 
     private:
-        void cptTumorRisk();            // assign values to d_tumorRisk    1
-        void cptTumorRisk(DoubleVect &ageValues,                        // 2
-                          Params const &params);
+        void cptTumorRisk();            // assign values to d_tumorRisk
 
-        static bool lifetimeRisk(StringVect &base, VSD &vsd);
-        static bool meanAge(StringVect &base, VSD &vsd);
-
-                                    // 'incidence' originally named 'carrier'
+                                   // 'incidence' originally named 'carrier'
         void setIncidence();        // sets d_params                    // 1
-        void setIncidence(StringVect &base, size_t idx,                 // 2
-                          bool setProbability);
 
-        static bool stdDev(StringVect &base, double &sd);
+        void setIncidence(StringVect &base, size_t idx, bool setProb);  // 2
 
         static bool valid(double sumProb);                              // .ih
-
         double sumProbs();
 
+// not used:        static bool onlyRiskTable(StringVect &base);
+
         static void writeCarrier(std::ostream &out, size_t idx,
                                  char type, double value);
-
-        // OBS: bool incidenceProb(StringVect const &base, Params &params);
 };
 
 #include "incidence.f"
