@@ -1,6 +1,8 @@
 #define XERR
 #include "loop.ih"
 
+    // by maybefalsenegative.cc
+
 bool Loop::falseNegative(ModBase *modBase)
 {
     // modified using Jing Wang's email (Tue, 20 Oct 2020 16:04:42 +0000)
@@ -13,7 +15,6 @@ bool Loop::falseNegative(ModBase *modBase)
     {
         g_log << "    detected FALSE_NEGATIVE (" << uval <<
                     " > sensitivity (" << sval << ")\n";
-        ++d_nRoundFN[d_round];
         d_roundInfo[d_round] = FALSE_NEGATIVE;
         return true;
     }
