@@ -4,6 +4,8 @@
 size_t g_caseIdx;           // -> loop.ih       if (caseIdx > 24842)
 size_t g_err = 14;
 
+    // by iterate.cc
+
 void Loop::genCases(size_t iter, size_t nCases)
 {
     CSVTable dataTable = headerData(iter);
@@ -22,8 +24,8 @@ void Loop::genCases(size_t iter, size_t nCases)
 
         postScreen();
 
-        d_sumDeathAge += d_deathAge;
-        d_totalCost += d_caseCost;
+//FBB        d_sumDeathAge += d_deathAge;
+//FBB        d_totalCost += d_caseCost;
 
         if (dataTable.stream() and (showAll or caseIdx + 1 == nCases))
         {
