@@ -1,10 +1,12 @@
 #define XERR
 #include "loop.ih"
 
+    // by analysis/run.cc
+
 void Loop::iterate()
 {
-    CSVTable sensTable = headerSensitivity();   // table to collect
-                                                // sensitivity values
+//FBB    CSVTable sensTable = headerSensitivity();   // table to collect
+//FBB                                                // sensitivity values
 
     Random::instance().setSeed(d_scenario.seed());
 
@@ -40,10 +42,10 @@ void Loop::iterate()
 
         writeRounds(rounds);        // -> ORG/loopendout.cpp
 
-        writeSensitivity(sensTable, idx);
+//FBB        writeSensitivity(sensTable, idx);
     }
 
-    if (sensTable.stream())
-        sensTable << hline();
+//FBB    if (sensTable.stream())
+//FBB        sensTable << hline();
 }
 
