@@ -78,7 +78,8 @@ class Loop: public Globals
             // Beir7 const &d_beir7;
             // Incidence const &d_incidence;
 
-    double d_sumDeathAge = 0;
+//FBB    double d_sumDeathAge = 0;
+
     double d_naturalDeathAge = 0;      // dying age w/o tumor
     double d_deathAge = 0;             // actual dying age
 
@@ -95,8 +96,12 @@ class Loop: public Globals
     SizeVect d_nTrueIntervals;          // # interval cancer per round
                                         //   following a previously attended
                                         //   screening round
-    SizeVect d_nRoundFP;                // # of false-positives per round
-    SizeVect d_nRoundFN;                // # of false-negatives per round
+
+//  initialized in resetcounters.cc
+//    SizeVect d_nRoundFP;                // # of false-positives per round
+//    SizeVect d_nRoundFN;                // # of false-negatives per round
+//    SizeVect d_nRoundTP;                // # of true-positives per round
+//    SizeVect d_nRoundTN;                // # of true-negatives per round
 
     SizeVect d_nDetections;
 
@@ -105,7 +110,7 @@ class Loop: public Globals
     double d_biopCosts;                 // sum of biop costs per case
     DoubleVect d_roundBiopCosts;        // and per round
 
-    double d_totalCost;
+//FBB    double d_totalCost;
 
     DoubleVect d_roundCost;             // sum of costs over all scr. rounds
                                         // (org: screeningRoundCosts)
@@ -142,9 +147,10 @@ class Loop: public Globals
         static void fillTNM(std::ostream &out);
         static void fillZeroes(std::ostream &out, size_t idx);
         void genCases(size_t iter, size_t nCases);
+
         FBB::CSVTable headerData(size_t iter) const;
         FBB::CSVTable headerRounds(size_t iter) const;
-        FBB::CSVTable headerSensitivity() const;
+//FBB        FBB::CSVTable headerSensitivity() const;
 
         bool intervalCancer();
 
@@ -156,7 +162,7 @@ class Loop: public Globals
         bool falseNegative(ModBase *modBase);
         void tumorDetected(ModBase *modBase, double screeningAge);
 
-        void maybeFalsePositive(ModBase *modBase, double screeningAge);
+        bool falsePositive(ModBase *modBase, double screeningAge);
 
         double naturalDeathAge();
         static void noTNM(std::ostream &out);
@@ -167,6 +173,13 @@ class Loop: public Globals
         static std::string replaceDollar(std::string const &settingsFile,
                                          size_t idx);
         void resetCounters();
+
+                                            // # active modalities
+        void roundsNcols(FBB::CSVTable &tab) const;
+        void roundsColHdrs(FBB::CSVTable &tab) const;
+        void roundsMidLevelCols(FBB::CSVTable &tab) const;
+        void roundsBottomColNames(FBB::CSVTable &tab) const;
+
                                             // returns the sensitivity for the
         double sensitivity(ModBase *modBase) const;    // current round  1.cc
 
@@ -186,21 +199,17 @@ class Loop: public Globals
         void writeData(FBB::CSVTable &dataTable, size_t idx) const;
         void writeParameters(size_t iter) const;    // also opens the file
         void writeRounds(FBB::CSVTable &roundTable) const;
-        void writeSensitivity(FBB::CSVTable &sensTable, size_t iter) const;
+//FBB        void writeSensitivity(FBB::CSVTable &sensTable, size_t iter) const;
 };
 
 
 // OBSOLETE
 //        void characteristics(Status natural, Status tumor);
-// OBSOLETE
 //        void preTumorDeath();   // early natural death
-// OBSOLETE
 //        void preScreen();
-// OBSOLETE
         void preSelfDetected();     // self detected tumor pre-screening
-// OBSOLETE: covered by 'left(...)'
+// covered by 'left(...)'
 //      void setStatus(Status status, double age);  // only sets the d_ vars.
-
 //        void removeCase(double screeningAge, double selfDetectAge);
 
 
