@@ -3,12 +3,24 @@
 
 extern size_t g_caseIdx;
 
+    // tumor does exist, but the screening may be negative: false negative
+    //                   otherwise: true positive
+
+        // by screen.cc
+
 void Loop::maybeFalseNegative(ModBase *modBase, double screeningAge)
 {
     d_tumor.characteristicsAt(screeningAge);
 
-    if (not falseNegative(modBase))
+    if (falseNegative(modBase))
+        // ++d_nRoundFN[d_round];
+        modBase->addFalseNegative(d_round);
+    else
+    {
         tumorDetected(modBase, screeningAge);
+        // ++d_nRoundTP[d_round];
+        modBase->addTruePositive(d_round);
+    }
 }
 
 
