@@ -25,8 +25,12 @@ void Loop::postScreen()
 
     d_deathAge = min(d_naturalDeathAge, d_tumor.deathAge());
 
-    left(d_tumor.selfDetectBefore(d_naturalDeathAge) ?
-        SELF_POST : UNDETECTED_POST,
+    left(
+        d_tumor.selfDetectBefore(d_naturalDeathAge) ? 
+            SELF_POST  : 
+            d_naturalDeathAge < d_tumor.onset() ? 
+                NATURAL_POST :
+                UNDETECTED_POST,
         d_deathAge);
          // d_tumor.selfDetectAge());
 }
