@@ -1,15 +1,15 @@
 //#define XERR
 #include "loop.ih"
 
+    // by iterate.cc
+
 void Loop::resetCounters()
 {
-    d_totalCost = 0;                        // org: womenCosts
-    d_sumDeathAge = 0;                      // org: womenYears
+//FBB    d_totalCost = 0;                        // org: womenCosts
+//FBB    d_sumDeathAge = 0;                      // org: womenYears
 
     d_nIntervals = SizeVect(d_nRounds);
     d_nTrueIntervals = SizeVect(d_nRounds);
-    d_nRoundFP = SizeVect(d_nRounds);    // # of false-positives per round
-    d_nRoundFN = SizeVect(d_nRounds);    // # of false-positives per round
     d_nDetections = SizeVect(d_nRounds);
     d_roundCost = DoubleVect(d_nRounds);
 
