@@ -1,7 +1,11 @@
-#define XERR
+#define XERR "loop"
 #include "loop.ih"
 
-    // perform a screening
+extern size_t g_caseIdx;
+
+// perform a screening
+
+    // by screening.cc
 
 void Loop::screen(double screeningAge)
 {
@@ -14,6 +18,9 @@ void Loop::screen(double screeningAge)
                                 d_screening.round(d_round).modalityIndices())
     )
     {
+        if (d_status != PRESENT)            // no screening if the case isn't
+            break;                          // present anymore
+
         if (not use(modBase))
             continue;
                                             // adds the basic costs: screening
@@ -29,11 +36,20 @@ void Loop::screen(double screeningAge)
         d_roundCost[d_round] += cost;
         g_log <<  d_roundCost[d_round] << '\n';
 
-        if (not d_tumor.at(screeningAge))   // no tumor, but screening may
-            maybeFalsePositive(modBase, screeningAge);  // detect a tumor
 
-        else                                // there is a tumor which may not
-            maybeFalseNegative(modBase, screeningAge);          // be detected
+        if (d_tumor.at(screeningAge))       // a tumor, but screening may
+            maybeFalseNegative(modBase, screeningAge);  // not detect it
+                            // otherwise: no tumor: if the biopsy shows a 
+                            // false positive the case leaves this screening
+                            // round
+        else if (falsePositive(modBase, screeningAge))  
+            break;
+
+//  was:
+//        if (not d_tumor.at(screeningAge))   // no tumor, but screening may
+//            maybeFalsePositive(modBase, screeningAge))  // detect a tumor
+//        else                                // there is a tumor which may not
+//            maybeFalseNegative(modBase, screeningAge);          // be detected
     }
 
     g_log << __FILE__ " completed screening at age " << screeningAge << '\n';
