@@ -1,8 +1,10 @@
-#define XERR
+#define XERR "loop"
 #include "loop.ih"
 
 extern size_t g_caseIdx;
 
+    // by gencases.cc
+
 void Loop::screening()
 {
     if (d_status == PRESENT and d_nRounds > 0)
