@@ -1,4 +1,4 @@
-#define XERR
+#define XERR "."
 #include "main.ih"
 
                             // update Options::alter, Options::inspect and
@@ -19,7 +19,6 @@ Arg::LongOption g_longOpts[] =
     Arg::LongOption{"one-analysis", 'o'},
     Arg::LongOption{"parameters",   'P'},
     Arg::LongOption{"rounds",       'R'},
-    Arg::LongOption{"sensitivity",  'S'},
     Arg::LongOption{"spread",       's'},
     Arg::LongOption{"tnm",          'T'},
     Arg::LongOption{"tumor-age",    't'},
@@ -27,13 +26,16 @@ Arg::LongOption g_longOpts[] =
     Arg::LongOption{"version",      'v'},
 };
 
+//FBB    Arg::LongOption{"sensitivity",  'S'},
+//FBB    Arg const &arg = Arg::initialize("a:B:c:C:d:D:el:hoP:R:S:s:t:TvV",
+
 auto const *g_longEnd = g_longOpts + size(g_longOpts);
 
 //main
 int main(int argc, char **argv)
 try
 {
-    Arg const &arg = Arg::initialize("a:B:c:C:d:D:el:hoP:R:S:s:t:TvV",
+    Arg const &arg = Arg::initialize("a:B:c:C:d:D:el:hoP:R:s:t:TvV",
                                       g_longOpts, g_longEnd, argc, argv);
     arg.versionHelp(usage, Icmake::version, arg.option('o') ? 0 : 1);
 
