@@ -3,7 +3,8 @@
 
 void Mammo::vInsert(ostream &out) const
 {
-    Globals::setPrecision(out, 2) <<
+    //Globals::setPrecision(out, 3) <<
+    Globals::setWidthPrec(out, 4, 3) <<
                 setw(4) << ' ' << "systematicError:  " << d_sysErr << '\n';
 
     VSD::fmt(6, "bi-rad:", 'a', 1, 0, 1, 0);
