@@ -7,3 +7,8 @@ inline void Modalities::activate(std::string const &modality)
 {
     d_active.emplace(modality);
 }
+
+inline std::vector<ModBase *> const &Modalities::activeMods() const
+{
+    return d_activeVect;
+}
