@@ -1,6 +1,8 @@
-#define XERR
+#define XERR "modalities"
 #include "modalities.ih"
 
+    // by loop/writerounds
+
 void Modalities::writeRounds(CSVTable &tab, size_t round) const
 {
     for (ModBase const *modBase: d_activeVect)           // insert the values
