@@ -22,7 +22,11 @@ class ModBase
 
     size_t d_cost = 0;                        // cost of using th modality
     SizeVect d_count;
-    uint16_t d_falsePositives;
+
+    SizeVect d_truePositives;               // separate counts for each
+    SizeVect d_falsePositives;              // round
+    SizeVect d_trueNegatives;
+    SizeVect d_falseNegatives;
 
     public:
         ModBase(std::string const &id);
@@ -33,7 +37,17 @@ class ModBase
         void count(size_t round);                                   // .f
         bool defined() const;                                       // .f
         double dose(uint16_t idx) const;                            // .f
-        void falsePositive();                                       // .f
+
+        void addTruePositive(size_t round);                         // .f
+        void addFalsePositive(size_t round);                        // .f
+        void addTrueNegative(size_t round);                         // .f
+        void addFalseNegative(size_t round);                        // .f
+
+        size_t truePositive(size_t round) const;                    // .f
+        size_t falsePositive(size_t round) const;                   // .f
+        size_t trueNegative(size_t round) const;                    // .f
+        size_t falseNegative(size_t round) const;                   // .f
+
         std::string const &id() const;                              // .f
         size_t operator[](size_t round) const;                      // .f
         void resetCounters(size_t nRounds);
