@@ -3,10 +3,10 @@
 
 std::ostream &operator<<(std::ostream &out, ModBase const &modBase)
 {
-    out << setw(8)  << ' ' << modBase.id() << ":\n" <<
-           setw(12) << ' ' << "cost:        " << modBase.d_cost << '\n';
+    out << "  " << modBase.id() << ":\n" <<
+           "    costs:        " << modBase.d_cost << '\n';
 
     modBase.vInsert(out);
 
-    return out;
+    return out.put('\n');
 }
