@@ -15,6 +15,6 @@ void Options::activate()
     d_dataFile[ANALYSIS]        = d_dataFile[STARTUP];
     d_parametersFile[ANALYSIS]  = d_parametersFile[STARTUP];
     d_roundsFile[ANALYSIS]      = d_roundsFile[STARTUP];
-    d_sensitivityFile[ANALYSIS] = d_sensitivityFile[STARTUP];
+//FBB    d_sensitivityFile[ANALYSIS] = d_sensitivityFile[STARTUP];
     d_spreadFile[ANALYSIS]      = d_spreadFile[STARTUP];
 }
