@@ -50,9 +50,9 @@ bool Options::alter(int optChar, std::string const &value)
             d_roundsFile[ANALYSIS] = value;
         break;
 
-        case 'S':
-            d_sensitivityFile[ANALYSIS] = value;
-        break;
+//FBB        case 'S':
+//FBB            d_sensitivityFile[ANALYSIS] = value;
+//FBB        break;
 
         case 's':
             d_spreadFile[ANALYSIS] = value;
