@@ -11,6 +11,7 @@ unordered_map<int, char const *> Options::s_fileName
     { 'D', "+data-$.txt"        },
     { 'P', ""                   },
     { 'R', "+rounds-$.txt"      },
-    { 'S', "+sensitivity.txt"   },
     { 's', "+spread-$.txt"      },
 };
+
+//FBB    { 'S', "+sensitivity.txt"   },
