@@ -3,6 +3,6 @@
 
 void Options::fixedNaturalDeathAge(double &deathAge) const
 {
-    if (d_specified.find('a') != string::npos)
+    if (d_specified[ANALYSIS].find('a') != string::npos)
         deathAge = d_naturalDeathAge;
 }
