@@ -53,7 +53,7 @@ class Options
                                     // after replacing + by base
     std::string d_parametersFile[2];
     std::string d_roundsFile[2];
-    std::string d_sensitivityFile[2];
+//FBB    std::string d_sensitivityFile[2];
 
     std::string d_spreadFile[2];
 
@@ -78,7 +78,7 @@ class Options
         std::string const &parametersFile() const;              // .f
         std::string const &dataFile() const;                    // .f
         std::string const &roundsFile() const;                  // .f
-        std::string const &sensitivityFile() const;             // .f
+//FBB        std::string const &sensitivityFile() const;             // .f
 
         std::string const &spreadFile() const;                  // .f
 
