@@ -24,7 +24,7 @@ Options::Options()
 
     fileOption(d_dataFile, 'D');
     fileOption(d_roundsFile, 'R');
-    fileOption(d_sensitivityFile, 'S');
+//FBB    fileOption(d_sensitivityFile, 'S');
     fileOption(d_spreadFile, 's');
     fileOption(d_parametersFile, 'P');
 
