@@ -1,7 +1,10 @@
-#define XERR
+#define XERR "parser"
 #include "parser.ih"
 
-    // load the configuration file 'fname'
+// load the configuration file 'fname'
+
+    // by analysis/analysis1.cc
+
 void Parser::load(string const &fname)
 {
     ConfigLines lines{ fname };
