@@ -1,4 +1,4 @@
-#define XERR
+//#define XERR
 #include "probgroup.ih"
 
 // see README.probgroup
@@ -18,7 +18,6 @@ RowCol ProbGroup::probIndexOf(Vector const &vect,
         if (group.contains(value))
         {
             uint16_t idx = group.indexOf(prob);
-
             return RowCol{ rowIdx, idx };
         }
         ++rowIdx;
