@@ -1,5 +1,4 @@
 //#define XERR
 #include "random.ih"
 
-Random Random::s_random;
-
+unique_ptr<Random> Random::s_random;
