@@ -1,9 +1,11 @@
 //#define XERR
 #include "round.ih"
 
+    // by round.f (operator<<)
+
 std::ostream &Round::insert(std::ostream &out) const
 {
-    out << "age: " << static_cast<size_t>(round(d_age));
+    Globals::setPrecision(out, 2) << "age: " << d_age;
 
     for (uint16_t modalityIdx: d_modalities)
         out << ", " << d_modalityIDs[modalityIdx];
