@@ -38,41 +38,12 @@ class Round
         std::ostream &insert(std::ostream &out) const;
 };
 
-inline bool Round::none() const
-{
-    return Globals::isZero(d_age - END_AGE);
-}
+#include "round.f"
 
-inline Round::Round(StringVect const &modalityIDs)
-:
-    d_modalityIDs(modalityIDs)
-{}
-
-inline  Uint16Vect const &Round::modalityIndices() const
-{
-    return d_modalities;
-}
-
-// inline  StringVect const &Round::modalityIDs() const
-// {
-//     return d_modalities;
-// }
-
-inline double Round::age() const
-{
-    return d_age;
-}
-
-inline uint16_t Round::rndAge() const
-{
-    return round(d_age);
-}
-
-inline std::ostream &operator<<(std::ostream &out, Round const &round)
-{
-    return round.insert(out);
-}
-
-typedef std::vector<Round> RoundVect;
+using RoundVect = std::vector<Round>;
 
 #endif
+
+
+
+
