@@ -34,7 +34,7 @@ class Modalities;
 
 class Screening
 {
-    Modalities const &d_modalities;
+    Modalities &d_modalities;
 
     StringVect d_base;
                                             // this vector's size holds the
@@ -52,7 +52,7 @@ class Screening
     bool d_lungCancer;
 
     public:
-        Screening(Modalities const &modalities);
+        Screening(Modalities &modalities);
 
         double rate() const;                                            // .f
 
