@@ -1,10 +1,10 @@
 #define XERR
 #include "screening.ih"
 
-Screening::Screening(Modalities const &modalities)
+Screening::Screening(Modalities &modalities)
 :
     d_modalities(modalities),
-    d_base{ "Screening:", "" },
+    d_base{ "" },
 
             // option -e is deprecated and is only available for reasons of
             // backward compatibility.
