@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "simulator.ih"
 
 Simulator::Simulator()
