@@ -1,6 +1,6 @@
-inline void Survival::setVSD(double diameter)
+inline RowCol Survival::setVSD(double diameter)
 {
-    (this->*d_cptVSDrow)(diameter); 
+    return (this->*d_cptVSDrow)(diameter);
 }
 
 inline bool Survival::metastatis() const
@@ -17,7 +17,7 @@ inline void Survival::vary(std::ostream &out)
 {
     (this->*d_vary)(out);
 }
-        
+
 inline void Survival::writeParameters(std::ostream &out) const
 {
     (this->*d_write)(out);      // writeBreast / writeLung
