@@ -27,6 +27,8 @@ class VSD
                             // meanCheck (VARY_MEAN), posCheck (VARY_NONNEG)
                             // probCheck (VARY_PROB). No checks for BETA_*,
     void (*d_valueCheck)(double &value);
+
+    bool d_exp;
                                                     // addresses of the
     static void (*s_valueCheck[])(double &value);   // ..Check functions
 
@@ -70,6 +72,8 @@ class VSD
                         unsigned valueIntWidth, unsigned valuePrec,
                         unsigned distValueWidth, unsigned distPrec);
 
+        void ln();                          // change 
+
                                             // write vary info to 'out'
         static void vary(std::ostream &out, // hdr should end in ':'    // 2
                         unsigned indent, char const *hdr,
